/* David Leonard <david.leonard@csee.uq.edu.au>, 1999. Public domain. */
#ifndef __h_functions_
#define __h_functions_

/* $Id: functions.h,v 1.2 2006/12/06 07:36:00 stroeder Exp $ */

#include "common.h"
extern void LDAPinit_functions( PyObject* );

#endif /* __h_functions_ */
